@@ -87,8 +87,25 @@ SECRET_KEY = random_string(24)
 TIMEZONE = 'Central Standard Time'  # 'Central Standard Time', 'Europe/London', 'Asia/Tokyo', ...
 
 
+# Default language
+DEFAULT_LANG = 'en'
+
+
+# Multi language
+MULTI_LANG = False      # True | False
+
+
+# Available laguages
+LANGUAGES = (
+    'en',   # English
+)
+
+
 # Global variables
 GLOBALS = {
     'key': 'Value',
 }
 
+
+# Project version
+VERSION = "1.0.0"
